@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.websecurityscanner_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -176,9 +187,9 @@ class WebSecurityScannerAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, WebSecurityScannerTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the web security scanner client.
@@ -222,16 +233,25 @@ class WebSecurityScannerAsyncClient:
 
     async def create_scan_config(
         self,
-        request: Union[web_security_scanner.CreateScanConfigRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.CreateScanConfigRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_config.ScanConfig:
         r"""Creates a new ScanConfig.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1
 
             async def sample_create_scan_config():
@@ -249,7 +269,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1.types.CreateScanConfigRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1.types.CreateScanConfigRequest, dict]]):
                 The request object. Request for the `CreateScanConfig`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -294,10 +314,12 @@ class WebSecurityScannerAsyncClient:
 
     async def delete_scan_config(
         self,
-        request: Union[web_security_scanner.DeleteScanConfigRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.DeleteScanConfigRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes an existing ScanConfig and its child
@@ -305,6 +327,13 @@ class WebSecurityScannerAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1
 
             async def sample_delete_scan_config():
@@ -319,7 +348,7 @@ class WebSecurityScannerAsyncClient:
                 await client.delete_scan_config(request=request)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1.types.DeleteScanConfigRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1.types.DeleteScanConfigRequest, dict]]):
                 The request object. Request for the `DeleteScanConfig`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -365,16 +394,25 @@ class WebSecurityScannerAsyncClient:
 
     async def get_scan_config(
         self,
-        request: Union[web_security_scanner.GetScanConfigRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.GetScanConfigRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_config.ScanConfig:
         r"""Gets a ScanConfig.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1
 
             async def sample_get_scan_config():
@@ -392,7 +430,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1.types.GetScanConfigRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1.types.GetScanConfigRequest, dict]]):
                 The request object. Request for the `GetScanConfig`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -447,16 +485,25 @@ class WebSecurityScannerAsyncClient:
 
     async def list_scan_configs(
         self,
-        request: Union[web_security_scanner.ListScanConfigsRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.ListScanConfigsRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListScanConfigsAsyncPager:
         r"""Lists ScanConfigs under a given project.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1
 
             async def sample_list_scan_configs():
@@ -475,7 +522,7 @@ class WebSecurityScannerAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1.types.ListScanConfigsRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1.types.ListScanConfigsRequest, dict]]):
                 The request object. Request for the `ListScanConfigs`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -541,10 +588,12 @@ class WebSecurityScannerAsyncClient:
 
     async def update_scan_config(
         self,
-        request: Union[web_security_scanner.UpdateScanConfigRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.UpdateScanConfigRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_config.ScanConfig:
         r"""Updates a ScanConfig. This method support partial
@@ -552,6 +601,13 @@ class WebSecurityScannerAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1
 
             async def sample_update_scan_config():
@@ -569,7 +625,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1.types.UpdateScanConfigRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1.types.UpdateScanConfigRequest, dict]]):
                 The request object. Request for the
                 `UpdateScanConfigRequest` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -616,16 +672,23 @@ class WebSecurityScannerAsyncClient:
 
     async def start_scan_run(
         self,
-        request: Union[web_security_scanner.StartScanRunRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.StartScanRunRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_run.ScanRun:
         r"""Start a ScanRun according to the given ScanConfig.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1
 
             async def sample_start_scan_run():
@@ -643,7 +706,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1.types.StartScanRunRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1.types.StartScanRunRequest, dict]]):
                 The request object. Request for the `StartScanRun`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -689,16 +752,23 @@ class WebSecurityScannerAsyncClient:
 
     async def get_scan_run(
         self,
-        request: Union[web_security_scanner.GetScanRunRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.GetScanRunRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_run.ScanRun:
         r"""Gets a ScanRun.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1
 
             async def sample_get_scan_run():
@@ -716,7 +786,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1.types.GetScanRunRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1.types.GetScanRunRequest, dict]]):
                 The request object. Request for the `GetScanRun` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -771,10 +841,10 @@ class WebSecurityScannerAsyncClient:
 
     async def list_scan_runs(
         self,
-        request: Union[web_security_scanner.ListScanRunsRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.ListScanRunsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListScanRunsAsyncPager:
         r"""Lists ScanRuns under a given ScanConfig, in
@@ -782,6 +852,13 @@ class WebSecurityScannerAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1
 
             async def sample_list_scan_runs():
@@ -800,7 +877,7 @@ class WebSecurityScannerAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1.types.ListScanRunsRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1.types.ListScanRunsRequest, dict]]):
                 The request object. Request for the `ListScanRuns`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -866,16 +943,23 @@ class WebSecurityScannerAsyncClient:
 
     async def stop_scan_run(
         self,
-        request: Union[web_security_scanner.StopScanRunRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.StopScanRunRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_run.ScanRun:
         r"""Stops a ScanRun. The stopped ScanRun is returned.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1
 
             async def sample_stop_scan_run():
@@ -893,7 +977,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1.types.StopScanRunRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1.types.StopScanRunRequest, dict]]):
                 The request object. Request for the `StopScanRun`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -939,16 +1023,25 @@ class WebSecurityScannerAsyncClient:
 
     async def list_crawled_urls(
         self,
-        request: Union[web_security_scanner.ListCrawledUrlsRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.ListCrawledUrlsRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListCrawledUrlsAsyncPager:
         r"""List CrawledUrls under a given ScanRun.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1
 
             async def sample_list_crawled_urls():
@@ -967,7 +1060,7 @@ class WebSecurityScannerAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1.types.ListCrawledUrlsRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1.types.ListCrawledUrlsRequest, dict]]):
                 The request object. Request for the `ListCrawledUrls`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1033,16 +1126,23 @@ class WebSecurityScannerAsyncClient:
 
     async def get_finding(
         self,
-        request: Union[web_security_scanner.GetFindingRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.GetFindingRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> finding.Finding:
         r"""Gets a Finding.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1
 
             async def sample_get_finding():
@@ -1060,7 +1160,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1.types.GetFindingRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1.types.GetFindingRequest, dict]]):
                 The request object. Request for the `GetFinding` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -1115,16 +1215,23 @@ class WebSecurityScannerAsyncClient:
 
     async def list_findings(
         self,
-        request: Union[web_security_scanner.ListFindingsRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.ListFindingsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListFindingsAsyncPager:
         r"""List Findings under a given ScanRun.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1
 
             async def sample_list_findings():
@@ -1143,7 +1250,7 @@ class WebSecurityScannerAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1.types.ListFindingsRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1.types.ListFindingsRequest, dict]]):
                 The request object. Request for the `ListFindings`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1209,16 +1316,25 @@ class WebSecurityScannerAsyncClient:
 
     async def list_finding_type_stats(
         self,
-        request: Union[web_security_scanner.ListFindingTypeStatsRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.ListFindingTypeStatsRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> web_security_scanner.ListFindingTypeStatsResponse:
         r"""List all FindingTypeStats under a given ScanRun.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1
 
             async def sample_list_finding_type_stats():
@@ -1236,7 +1352,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1.types.ListFindingTypeStatsRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1.types.ListFindingTypeStatsRequest, dict]]):
                 The request object. Request for the
                 `ListFindingTypeStats` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1294,14 +1410,9 @@ class WebSecurityScannerAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-websecurityscanner",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("WebSecurityScannerAsyncClient",)
