@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 __protobuf__ = proto.module(
@@ -44,8 +46,9 @@ class ScanRunWarningTrace(proto.Message):
         TOO_MANY_CRAWL_RESULTS = 2
         TOO_MANY_FUZZ_TASKS = 3
         BLOCKED_BY_IAP = 4
+        NO_STARTING_URL_FOUND_FOR_MANAGED_SCAN = 5
 
-    code = proto.Field(
+    code: Code = proto.Field(
         proto.ENUM,
         number=1,
         enum=Code,
