@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 from google.protobuf import field_mask_pb2  # type: ignore
 import proto  # type: ignore
 
@@ -61,11 +63,11 @@ class CreateScanConfigRequest(proto.Message):
             Required. The ScanConfig to be created.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    scan_config = proto.Field(
+    scan_config: gcw_scan_config.ScanConfig = proto.Field(
         proto.MESSAGE,
         number=2,
         message=gcw_scan_config.ScanConfig,
@@ -82,7 +84,7 @@ class DeleteScanConfigRequest(proto.Message):
             'projects/{projectId}/scanConfigs/{scanConfigId}'.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -98,7 +100,7 @@ class GetScanConfigRequest(proto.Message):
             'projects/{projectId}/scanConfigs/{scanConfigId}'.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -124,15 +126,15 @@ class ListScanConfigsRequest(proto.Message):
             reasonable value.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=3,
     )
@@ -153,12 +155,12 @@ class UpdateScanConfigRequest(proto.Message):
             https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask
     """
 
-    scan_config = proto.Field(
+    scan_config: gcw_scan_config.ScanConfig = proto.Field(
         proto.MESSAGE,
         number=2,
         message=gcw_scan_config.ScanConfig,
     )
-    update_mask = proto.Field(
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
         proto.MESSAGE,
         number=3,
         message=field_mask_pb2.FieldMask,
@@ -169,7 +171,7 @@ class ListScanConfigsResponse(proto.Message):
     r"""Response for the ``ListScanConfigs`` method.
 
     Attributes:
-        scan_configs (Sequence[google.cloud.websecurityscanner_v1.types.ScanConfig]):
+        scan_configs (MutableSequence[google.cloud.websecurityscanner_v1.types.ScanConfig]):
             The list of ScanConfigs returned.
         next_page_token (str):
             Token to retrieve the next page of results,
@@ -181,12 +183,12 @@ class ListScanConfigsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    scan_configs = proto.RepeatedField(
+    scan_configs: MutableSequence[gcw_scan_config.ScanConfig] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=gcw_scan_config.ScanConfig,
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -202,7 +204,7 @@ class StartScanRunRequest(proto.Message):
             'projects/{projectId}/scanConfigs/{scanConfigId}'.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -218,7 +220,7 @@ class GetScanRunRequest(proto.Message):
             'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -244,15 +246,15 @@ class ListScanRunsRequest(proto.Message):
             reasonable value.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=3,
     )
@@ -262,7 +264,7 @@ class ListScanRunsResponse(proto.Message):
     r"""Response for the ``ListScanRuns`` method.
 
     Attributes:
-        scan_runs (Sequence[google.cloud.websecurityscanner_v1.types.ScanRun]):
+        scan_runs (MutableSequence[google.cloud.websecurityscanner_v1.types.ScanRun]):
             The list of ScanRuns returned.
         next_page_token (str):
             Token to retrieve the next page of results,
@@ -274,12 +276,12 @@ class ListScanRunsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    scan_runs = proto.RepeatedField(
+    scan_runs: MutableSequence[scan_run.ScanRun] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=scan_run.ScanRun,
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -295,7 +297,7 @@ class StopScanRunRequest(proto.Message):
             'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -321,15 +323,15 @@ class ListCrawledUrlsRequest(proto.Message):
             reasonable value.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=3,
     )
@@ -339,7 +341,7 @@ class ListCrawledUrlsResponse(proto.Message):
     r"""Response for the ``ListCrawledUrls`` method.
 
     Attributes:
-        crawled_urls (Sequence[google.cloud.websecurityscanner_v1.types.CrawledUrl]):
+        crawled_urls (MutableSequence[google.cloud.websecurityscanner_v1.types.CrawledUrl]):
             The list of CrawledUrls returned.
         next_page_token (str):
             Token to retrieve the next page of results,
@@ -351,12 +353,12 @@ class ListCrawledUrlsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    crawled_urls = proto.RepeatedField(
+    crawled_urls: MutableSequence[crawled_url.CrawledUrl] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=crawled_url.CrawledUrl,
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -372,7 +374,7 @@ class GetFindingRequest(proto.Message):
             'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}/findings/{findingId}'.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -401,19 +403,19 @@ class ListFindingsRequest(proto.Message):
             reasonable value.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    filter = proto.Field(
+    filter: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=4,
     )
@@ -423,7 +425,7 @@ class ListFindingsResponse(proto.Message):
     r"""Response for the ``ListFindings`` method.
 
     Attributes:
-        findings (Sequence[google.cloud.websecurityscanner_v1.types.Finding]):
+        findings (MutableSequence[google.cloud.websecurityscanner_v1.types.Finding]):
             The list of Findings returned.
         next_page_token (str):
             Token to retrieve the next page of results,
@@ -435,12 +437,12 @@ class ListFindingsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    findings = proto.RepeatedField(
+    findings: MutableSequence[finding.Finding] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=finding.Finding,
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -456,7 +458,7 @@ class ListFindingTypeStatsRequest(proto.Message):
             'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -466,11 +468,13 @@ class ListFindingTypeStatsResponse(proto.Message):
     r"""Response for the ``ListFindingTypeStats`` method.
 
     Attributes:
-        finding_type_stats (Sequence[google.cloud.websecurityscanner_v1.types.FindingTypeStats]):
+        finding_type_stats (MutableSequence[google.cloud.websecurityscanner_v1.types.FindingTypeStats]):
             The list of FindingTypeStats returned.
     """
 
-    finding_type_stats = proto.RepeatedField(
+    finding_type_stats: MutableSequence[
+        gcw_finding_type_stats.FindingTypeStats
+    ] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=gcw_finding_type_stats.FindingTypeStats,
