@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.websecurityscanner_v1alpha import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -181,9 +192,9 @@ class WebSecurityScannerAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, WebSecurityScannerTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the web security scanner client.
@@ -227,12 +238,14 @@ class WebSecurityScannerAsyncClient:
 
     async def create_scan_config(
         self,
-        request: Union[web_security_scanner.CreateScanConfigRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.CreateScanConfigRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
-        scan_config: gcw_scan_config.ScanConfig = None,
+        parent: Optional[str] = None,
+        scan_config: Optional[gcw_scan_config.ScanConfig] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gcw_scan_config.ScanConfig:
         r"""Creates a new ScanConfig.
@@ -269,7 +282,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1alpha.types.CreateScanConfigRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1alpha.types.CreateScanConfigRequest, dict]]):
                 The request object. Request for the `CreateScanConfig`
                 method.
             parent (:class:`str`):
@@ -347,11 +360,13 @@ class WebSecurityScannerAsyncClient:
 
     async def delete_scan_config(
         self,
-        request: Union[web_security_scanner.DeleteScanConfigRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.DeleteScanConfigRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes an existing ScanConfig and its child
@@ -381,7 +396,7 @@ class WebSecurityScannerAsyncClient:
                 await client.delete_scan_config(request=request)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1alpha.types.DeleteScanConfigRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1alpha.types.DeleteScanConfigRequest, dict]]):
                 The request object. Request for the `DeleteScanConfig`
                 method.
             name (:class:`str`):
@@ -450,11 +465,13 @@ class WebSecurityScannerAsyncClient:
 
     async def get_scan_config(
         self,
-        request: Union[web_security_scanner.GetScanConfigRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.GetScanConfigRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_config.ScanConfig:
         r"""Gets a ScanConfig.
@@ -486,7 +503,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1alpha.types.GetScanConfigRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1alpha.types.GetScanConfigRequest, dict]]):
                 The request object. Request for the `GetScanConfig`
                 method.
             name (:class:`str`):
@@ -565,11 +582,13 @@ class WebSecurityScannerAsyncClient:
 
     async def list_scan_configs(
         self,
-        request: Union[web_security_scanner.ListScanConfigsRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.ListScanConfigsRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListScanConfigsAsyncPager:
         r"""Lists ScanConfigs under a given project.
@@ -602,7 +621,7 @@ class WebSecurityScannerAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1alpha.types.ListScanConfigsRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1alpha.types.ListScanConfigsRequest, dict]]):
                 The request object. Request for the `ListScanConfigs`
                 method.
             parent (:class:`str`):
@@ -690,12 +709,14 @@ class WebSecurityScannerAsyncClient:
 
     async def update_scan_config(
         self,
-        request: Union[web_security_scanner.UpdateScanConfigRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.UpdateScanConfigRequest, dict]
+        ] = None,
         *,
-        scan_config: gcw_scan_config.ScanConfig = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        scan_config: Optional[gcw_scan_config.ScanConfig] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gcw_scan_config.ScanConfig:
         r"""Updates a ScanConfig. This method support partial
@@ -732,7 +753,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1alpha.types.UpdateScanConfigRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1alpha.types.UpdateScanConfigRequest, dict]]):
                 The request object. Request for the
                 `UpdateScanConfigRequest` method.
             scan_config (:class:`google.cloud.websecurityscanner_v1alpha.types.ScanConfig`):
@@ -814,11 +835,11 @@ class WebSecurityScannerAsyncClient:
 
     async def start_scan_run(
         self,
-        request: Union[web_security_scanner.StartScanRunRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.StartScanRunRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_run.ScanRun:
         r"""Start a ScanRun according to the given ScanConfig.
@@ -850,7 +871,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1alpha.types.StartScanRunRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1alpha.types.StartScanRunRequest, dict]]):
                 The request object. Request for the `StartScanRun`
                 method.
             name (:class:`str`):
@@ -918,11 +939,11 @@ class WebSecurityScannerAsyncClient:
 
     async def get_scan_run(
         self,
-        request: Union[web_security_scanner.GetScanRunRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.GetScanRunRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_run.ScanRun:
         r"""Gets a ScanRun.
@@ -954,7 +975,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1alpha.types.GetScanRunRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1alpha.types.GetScanRunRequest, dict]]):
                 The request object. Request for the `GetScanRun` method.
             name (:class:`str`):
                 Required. The resource name of the
@@ -1031,11 +1052,11 @@ class WebSecurityScannerAsyncClient:
 
     async def list_scan_runs(
         self,
-        request: Union[web_security_scanner.ListScanRunsRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.ListScanRunsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListScanRunsAsyncPager:
         r"""Lists ScanRuns under a given ScanConfig, in
@@ -1069,7 +1090,7 @@ class WebSecurityScannerAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1alpha.types.ListScanRunsRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1alpha.types.ListScanRunsRequest, dict]]):
                 The request object. Request for the `ListScanRuns`
                 method.
             parent (:class:`str`):
@@ -1158,11 +1179,11 @@ class WebSecurityScannerAsyncClient:
 
     async def stop_scan_run(
         self,
-        request: Union[web_security_scanner.StopScanRunRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.StopScanRunRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_run.ScanRun:
         r"""Stops a ScanRun. The stopped ScanRun is returned.
@@ -1194,7 +1215,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1alpha.types.StopScanRunRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1alpha.types.StopScanRunRequest, dict]]):
                 The request object. Request for the `StopScanRun`
                 method.
             name (:class:`str`):
@@ -1262,11 +1283,13 @@ class WebSecurityScannerAsyncClient:
 
     async def list_crawled_urls(
         self,
-        request: Union[web_security_scanner.ListCrawledUrlsRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.ListCrawledUrlsRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListCrawledUrlsAsyncPager:
         r"""List CrawledUrls under a given ScanRun.
@@ -1299,7 +1322,7 @@ class WebSecurityScannerAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1alpha.types.ListCrawledUrlsRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1alpha.types.ListCrawledUrlsRequest, dict]]):
                 The request object. Request for the `ListCrawledUrls`
                 method.
             parent (:class:`str`):
@@ -1388,11 +1411,11 @@ class WebSecurityScannerAsyncClient:
 
     async def get_finding(
         self,
-        request: Union[web_security_scanner.GetFindingRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.GetFindingRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> finding.Finding:
         r"""Gets a Finding.
@@ -1424,7 +1447,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1alpha.types.GetFindingRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1alpha.types.GetFindingRequest, dict]]):
                 The request object. Request for the `GetFinding` method.
             name (:class:`str`):
                 Required. The resource name of the
@@ -1502,12 +1525,12 @@ class WebSecurityScannerAsyncClient:
 
     async def list_findings(
         self,
-        request: Union[web_security_scanner.ListFindingsRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.ListFindingsRequest, dict]] = None,
         *,
-        parent: str = None,
-        filter: str = None,
+        parent: Optional[str] = None,
+        filter: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListFindingsAsyncPager:
         r"""List Findings under a given ScanRun.
@@ -1541,7 +1564,7 @@ class WebSecurityScannerAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1alpha.types.ListFindingsRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1alpha.types.ListFindingsRequest, dict]]):
                 The request object. Request for the `ListFindings`
                 method.
             parent (:class:`str`):
@@ -1640,11 +1663,13 @@ class WebSecurityScannerAsyncClient:
 
     async def list_finding_type_stats(
         self,
-        request: Union[web_security_scanner.ListFindingTypeStatsRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.ListFindingTypeStatsRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> web_security_scanner.ListFindingTypeStatsResponse:
         r"""List all FindingTypeStats under a given ScanRun.
@@ -1676,7 +1701,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1alpha.types.ListFindingTypeStatsRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1alpha.types.ListFindingTypeStatsRequest, dict]]):
                 The request object. Request for the
                 `ListFindingTypeStats` method.
             parent (:class:`str`):
@@ -1757,14 +1782,9 @@ class WebSecurityScannerAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-websecurityscanner",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("WebSecurityScannerAsyncClient",)
