@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.websecurityscanner_v1alpha import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -69,7 +81,7 @@ class WebSecurityScannerClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[WebSecurityScannerTransport]:
         """Returns an appropriate transport class.
 
@@ -393,8 +405,8 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, WebSecurityScannerTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, WebSecurityScannerTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the web security scanner client.
@@ -408,7 +420,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
             transport (Union[str, WebSecurityScannerTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -438,6 +450,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -490,12 +503,14 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def create_scan_config(
         self,
-        request: Union[web_security_scanner.CreateScanConfigRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.CreateScanConfigRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
-        scan_config: gcw_scan_config.ScanConfig = None,
+        parent: Optional[str] = None,
+        scan_config: Optional[gcw_scan_config.ScanConfig] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gcw_scan_config.ScanConfig:
         r"""Creates a new ScanConfig.
@@ -610,11 +625,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def delete_scan_config(
         self,
-        request: Union[web_security_scanner.DeleteScanConfigRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.DeleteScanConfigRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes an existing ScanConfig and its child
@@ -703,11 +720,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def get_scan_config(
         self,
-        request: Union[web_security_scanner.GetScanConfigRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.GetScanConfigRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_config.ScanConfig:
         r"""Gets a ScanConfig.
@@ -808,11 +827,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def list_scan_configs(
         self,
-        request: Union[web_security_scanner.ListScanConfigsRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.ListScanConfigsRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListScanConfigsPager:
         r"""Lists ScanConfigs under a given project.
@@ -923,12 +944,14 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def update_scan_config(
         self,
-        request: Union[web_security_scanner.UpdateScanConfigRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.UpdateScanConfigRequest, dict]
+        ] = None,
         *,
-        scan_config: gcw_scan_config.ScanConfig = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        scan_config: Optional[gcw_scan_config.ScanConfig] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gcw_scan_config.ScanConfig:
         r"""Updates a ScanConfig. This method support partial
@@ -1047,11 +1070,11 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def start_scan_run(
         self,
-        request: Union[web_security_scanner.StartScanRunRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.StartScanRunRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_run.ScanRun:
         r"""Start a ScanRun according to the given ScanConfig.
@@ -1151,11 +1174,11 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def get_scan_run(
         self,
-        request: Union[web_security_scanner.GetScanRunRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.GetScanRunRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_run.ScanRun:
         r"""Gets a ScanRun.
@@ -1254,11 +1277,11 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def list_scan_runs(
         self,
-        request: Union[web_security_scanner.ListScanRunsRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.ListScanRunsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListScanRunsPager:
         r"""Lists ScanRuns under a given ScanConfig, in
@@ -1371,11 +1394,11 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def stop_scan_run(
         self,
-        request: Union[web_security_scanner.StopScanRunRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.StopScanRunRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_run.ScanRun:
         r"""Stops a ScanRun. The stopped ScanRun is returned.
@@ -1475,11 +1498,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def list_crawled_urls(
         self,
-        request: Union[web_security_scanner.ListCrawledUrlsRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.ListCrawledUrlsRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListCrawledUrlsPager:
         r"""List CrawledUrls under a given ScanRun.
@@ -1591,11 +1616,11 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def get_finding(
         self,
-        request: Union[web_security_scanner.GetFindingRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.GetFindingRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> finding.Finding:
         r"""Gets a Finding.
@@ -1695,12 +1720,12 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def list_findings(
         self,
-        request: Union[web_security_scanner.ListFindingsRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.ListFindingsRequest, dict]] = None,
         *,
-        parent: str = None,
-        filter: str = None,
+        parent: Optional[str] = None,
+        filter: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListFindingsPager:
         r"""List Findings under a given ScanRun.
@@ -1823,11 +1848,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def list_finding_type_stats(
         self,
-        request: Union[web_security_scanner.ListFindingTypeStatsRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.ListFindingTypeStatsRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> web_security_scanner.ListFindingTypeStatsResponse:
         r"""List all FindingTypeStats under a given ScanRun.
@@ -1937,14 +1964,9 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-websecurityscanner",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("WebSecurityScannerClient",)
