@@ -24,21 +24,16 @@ import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
-import pkg_resources
 
+from google.cloud.websecurityscanner_v1alpha import gapic_version as package_version
 from google.cloud.websecurityscanner_v1alpha.types import scan_run, web_security_scanner
 from google.cloud.websecurityscanner_v1alpha.types import scan_config as gcw_scan_config
 from google.cloud.websecurityscanner_v1alpha.types import finding
 from google.cloud.websecurityscanner_v1alpha.types import scan_config
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-websecurityscanner",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 class WebSecurityScannerTransport(abc.ABC):
@@ -52,7 +47,7 @@ class WebSecurityScannerTransport(abc.ABC):
         self,
         *,
         host: str = DEFAULT_HOST,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
