@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.websecurityscanner_v1beta import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -186,9 +197,9 @@ class WebSecurityScannerAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, WebSecurityScannerTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the web security scanner client.
@@ -232,18 +243,27 @@ class WebSecurityScannerAsyncClient:
 
     async def create_scan_config(
         self,
-        request: Union[web_security_scanner.CreateScanConfigRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.CreateScanConfigRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
-        scan_config: gcw_scan_config.ScanConfig = None,
+        parent: Optional[str] = None,
+        scan_config: Optional[gcw_scan_config.ScanConfig] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gcw_scan_config.ScanConfig:
         r"""Creates a new ScanConfig.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             async def sample_create_scan_config():
@@ -253,7 +273,7 @@ class WebSecurityScannerAsyncClient:
                 # Initialize request argument(s)
                 scan_config = websecurityscanner_v1beta.ScanConfig()
                 scan_config.display_name = "display_name_value"
-                scan_config.starting_urls = ['starting_urls_value_1', 'starting_urls_value_2']
+                scan_config.starting_urls = ['starting_urls_value1', 'starting_urls_value2']
 
                 request = websecurityscanner_v1beta.CreateScanConfigRequest(
                     parent="parent_value",
@@ -267,7 +287,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1beta.types.CreateScanConfigRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1beta.types.CreateScanConfigRequest, dict]]):
                 The request object. Request for the `CreateScanConfig`
                 method.
             parent (:class:`str`):
@@ -344,11 +364,13 @@ class WebSecurityScannerAsyncClient:
 
     async def delete_scan_config(
         self,
-        request: Union[web_security_scanner.DeleteScanConfigRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.DeleteScanConfigRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes an existing ScanConfig and its child
@@ -356,6 +378,13 @@ class WebSecurityScannerAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             async def sample_delete_scan_config():
@@ -371,7 +400,7 @@ class WebSecurityScannerAsyncClient:
                 await client.delete_scan_config(request=request)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1beta.types.DeleteScanConfigRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1beta.types.DeleteScanConfigRequest, dict]]):
                 The request object. Request for the `DeleteScanConfig`
                 method.
             name (:class:`str`):
@@ -440,17 +469,26 @@ class WebSecurityScannerAsyncClient:
 
     async def get_scan_config(
         self,
-        request: Union[web_security_scanner.GetScanConfigRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.GetScanConfigRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_config.ScanConfig:
         r"""Gets a ScanConfig.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             async def sample_get_scan_config():
@@ -469,7 +507,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1beta.types.GetScanConfigRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1beta.types.GetScanConfigRequest, dict]]):
                 The request object. Request for the `GetScanConfig`
                 method.
             name (:class:`str`):
@@ -547,17 +585,26 @@ class WebSecurityScannerAsyncClient:
 
     async def list_scan_configs(
         self,
-        request: Union[web_security_scanner.ListScanConfigsRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.ListScanConfigsRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListScanConfigsAsyncPager:
         r"""Lists ScanConfigs under a given project.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             async def sample_list_scan_configs():
@@ -577,7 +624,7 @@ class WebSecurityScannerAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1beta.types.ListScanConfigsRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1beta.types.ListScanConfigsRequest, dict]]):
                 The request object. Request for the `ListScanConfigs`
                 method.
             parent (:class:`str`):
@@ -665,12 +712,14 @@ class WebSecurityScannerAsyncClient:
 
     async def update_scan_config(
         self,
-        request: Union[web_security_scanner.UpdateScanConfigRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.UpdateScanConfigRequest, dict]
+        ] = None,
         *,
-        scan_config: gcw_scan_config.ScanConfig = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        scan_config: Optional[gcw_scan_config.ScanConfig] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gcw_scan_config.ScanConfig:
         r"""Updates a ScanConfig. This method support partial
@@ -678,6 +727,13 @@ class WebSecurityScannerAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             async def sample_update_scan_config():
@@ -687,7 +743,7 @@ class WebSecurityScannerAsyncClient:
                 # Initialize request argument(s)
                 scan_config = websecurityscanner_v1beta.ScanConfig()
                 scan_config.display_name = "display_name_value"
-                scan_config.starting_urls = ['starting_urls_value_1', 'starting_urls_value_2']
+                scan_config.starting_urls = ['starting_urls_value1', 'starting_urls_value2']
 
                 request = websecurityscanner_v1beta.UpdateScanConfigRequest(
                     scan_config=scan_config,
@@ -700,7 +756,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1beta.types.UpdateScanConfigRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1beta.types.UpdateScanConfigRequest, dict]]):
                 The request object. Request for the
                 `UpdateScanConfigRequest` method.
             scan_config (:class:`google.cloud.websecurityscanner_v1beta.types.ScanConfig`):
@@ -781,17 +837,24 @@ class WebSecurityScannerAsyncClient:
 
     async def start_scan_run(
         self,
-        request: Union[web_security_scanner.StartScanRunRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.StartScanRunRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_run.ScanRun:
         r"""Start a ScanRun according to the given ScanConfig.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             async def sample_start_scan_run():
@@ -810,7 +873,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1beta.types.StartScanRunRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1beta.types.StartScanRunRequest, dict]]):
                 The request object. Request for the `StartScanRun`
                 method.
             name (:class:`str`):
@@ -879,17 +942,24 @@ class WebSecurityScannerAsyncClient:
 
     async def get_scan_run(
         self,
-        request: Union[web_security_scanner.GetScanRunRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.GetScanRunRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_run.ScanRun:
         r"""Gets a ScanRun.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             async def sample_get_scan_run():
@@ -908,7 +978,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1beta.types.GetScanRunRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1beta.types.GetScanRunRequest, dict]]):
                 The request object. Request for the `GetScanRun` method.
             name (:class:`str`):
                 Required. The resource name of the
@@ -986,11 +1056,11 @@ class WebSecurityScannerAsyncClient:
 
     async def list_scan_runs(
         self,
-        request: Union[web_security_scanner.ListScanRunsRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.ListScanRunsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListScanRunsAsyncPager:
         r"""Lists ScanRuns under a given ScanConfig, in
@@ -998,6 +1068,13 @@ class WebSecurityScannerAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             async def sample_list_scan_runs():
@@ -1017,7 +1094,7 @@ class WebSecurityScannerAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1beta.types.ListScanRunsRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1beta.types.ListScanRunsRequest, dict]]):
                 The request object. Request for the `ListScanRuns`
                 method.
             parent (:class:`str`):
@@ -1106,17 +1183,24 @@ class WebSecurityScannerAsyncClient:
 
     async def stop_scan_run(
         self,
-        request: Union[web_security_scanner.StopScanRunRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.StopScanRunRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_run.ScanRun:
         r"""Stops a ScanRun. The stopped ScanRun is returned.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             async def sample_stop_scan_run():
@@ -1135,7 +1219,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1beta.types.StopScanRunRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1beta.types.StopScanRunRequest, dict]]):
                 The request object. Request for the `StopScanRun`
                 method.
             name (:class:`str`):
@@ -1204,17 +1288,26 @@ class WebSecurityScannerAsyncClient:
 
     async def list_crawled_urls(
         self,
-        request: Union[web_security_scanner.ListCrawledUrlsRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.ListCrawledUrlsRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListCrawledUrlsAsyncPager:
         r"""List CrawledUrls under a given ScanRun.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             async def sample_list_crawled_urls():
@@ -1234,7 +1327,7 @@ class WebSecurityScannerAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1beta.types.ListCrawledUrlsRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1beta.types.ListCrawledUrlsRequest, dict]]):
                 The request object. Request for the `ListCrawledUrls`
                 method.
             parent (:class:`str`):
@@ -1323,17 +1416,24 @@ class WebSecurityScannerAsyncClient:
 
     async def get_finding(
         self,
-        request: Union[web_security_scanner.GetFindingRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.GetFindingRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> finding.Finding:
         r"""Gets a Finding.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             async def sample_get_finding():
@@ -1352,7 +1452,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1beta.types.GetFindingRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1beta.types.GetFindingRequest, dict]]):
                 The request object. Request for the `GetFinding` method.
             name (:class:`str`):
                 Required. The resource name of the
@@ -1430,18 +1530,25 @@ class WebSecurityScannerAsyncClient:
 
     async def list_findings(
         self,
-        request: Union[web_security_scanner.ListFindingsRequest, dict] = None,
+        request: Optional[Union[web_security_scanner.ListFindingsRequest, dict]] = None,
         *,
-        parent: str = None,
-        filter: str = None,
+        parent: Optional[str] = None,
+        filter: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListFindingsAsyncPager:
         r"""List Findings under a given ScanRun.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             async def sample_list_findings():
@@ -1462,7 +1569,7 @@ class WebSecurityScannerAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1beta.types.ListFindingsRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1beta.types.ListFindingsRequest, dict]]):
                 The request object. Request for the `ListFindings`
                 method.
             parent (:class:`str`):
@@ -1561,17 +1668,26 @@ class WebSecurityScannerAsyncClient:
 
     async def list_finding_type_stats(
         self,
-        request: Union[web_security_scanner.ListFindingTypeStatsRequest, dict] = None,
+        request: Optional[
+            Union[web_security_scanner.ListFindingTypeStatsRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> web_security_scanner.ListFindingTypeStatsResponse:
         r"""List all FindingTypeStats under a given ScanRun.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             async def sample_list_finding_type_stats():
@@ -1590,7 +1706,7 @@ class WebSecurityScannerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.websecurityscanner_v1beta.types.ListFindingTypeStatsRequest, dict]):
+            request (Optional[Union[google.cloud.websecurityscanner_v1beta.types.ListFindingTypeStatsRequest, dict]]):
                 The request object. Request for the
                 `ListFindingTypeStats` method.
             parent (:class:`str`):
@@ -1671,14 +1787,9 @@ class WebSecurityScannerAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-websecurityscanner",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("WebSecurityScannerAsyncClient",)
